Loader

Struct Loader 

pub struct Loader;
The type corresponding to the Loader protocol. See //docs/concepts/process/program_loading.md for a more complete description of this and related process bootstrapping protocols, and for specifics about the default global loader service’s interpretation of names, paths, and configurations.