#[repr(C)]pub struct LoaderCloneResponse {
pub rv: Int32,
}Expand description
The wire type corresponding to LoaderCloneResponse.
Fields
rv: Int32Trait Implementations
Sourceimpl Clone for LoaderCloneResponse
impl Clone for LoaderCloneResponse
Sourcefn clone(&self) -> LoaderCloneResponse
fn clone(&self) -> LoaderCloneResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for LoaderCloneResponse
impl Constrained for LoaderCloneResponse
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, LoaderCloneResponse>,
_: <LoaderCloneResponse as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, LoaderCloneResponse>, _: <LoaderCloneResponse as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for LoaderCloneResponse
impl Debug for LoaderCloneResponse
Sourceimpl<___D> Decode<___D> for LoaderCloneResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for LoaderCloneResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<LoaderCloneResponse, ___E> for &'a LoaderCloneResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<LoaderCloneResponse, ___E> for &'a LoaderCloneResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LoaderCloneResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LoaderCloneResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LoaderCloneResponse, ___E> for LoaderCloneResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<LoaderCloneResponse, ___E> for LoaderCloneResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LoaderCloneResponse, LoaderCloneResponse>
const COPY_OPTIMIZATION: CopyOptimization<LoaderCloneResponse, LoaderCloneResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LoaderCloneResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LoaderCloneResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<LoaderCloneResponse, ___E> for LoaderCloneResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
impl<___E, T0> Encode<LoaderCloneResponse, ___E> for LoaderCloneResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int32, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LoaderCloneResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LoaderCloneResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<LoaderCloneResponse> for LoaderCloneResponse
impl FromWire<LoaderCloneResponse> for LoaderCloneResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LoaderCloneResponse, LoaderCloneResponse>
const COPY_OPTIMIZATION: CopyOptimization<LoaderCloneResponse, LoaderCloneResponse>
Sourcefn from_wire(wire: LoaderCloneResponse) -> LoaderCloneResponse
fn from_wire(wire: LoaderCloneResponse) -> LoaderCloneResponse
Converts the given owned value to this type.
Sourceimpl FromWireRef<LoaderCloneResponse> for LoaderCloneResponse
impl FromWireRef<LoaderCloneResponse> for LoaderCloneResponse
Sourcefn from_wire_ref(wire: &LoaderCloneResponse) -> LoaderCloneResponse
fn from_wire_ref(wire: &LoaderCloneResponse) -> LoaderCloneResponse
Converts the given reference to this type.
Sourceimpl IntoNatural for LoaderCloneResponse
impl IntoNatural for LoaderCloneResponse
Sourcetype Natural = LoaderCloneResponse
type Natural = LoaderCloneResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for LoaderCloneResponse
impl Wire for LoaderCloneResponse
Sourcetype Narrowed<'de> = LoaderCloneResponse
type Narrowed<'de> = LoaderCloneResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<LoaderCloneResponse>)
fn zero_padding(out_: &mut MaybeUninit<LoaderCloneResponse>)
Writes zeroes to the padding for this type, if any.