#[repr(C)]pub struct LoaderLoadObjectResponse {
pub rv: Int32,
pub object: OptionalVmo,
}Expand description
The wire type corresponding to LoaderLoadObjectResponse.
Fields
rv: Int32object: OptionalVmoTrait Implementations
Sourceimpl Constrained for LoaderLoadObjectResponse
impl Constrained for LoaderLoadObjectResponse
Sourceimpl Debug for LoaderLoadObjectResponse
impl Debug for LoaderLoadObjectResponse
Sourceimpl<___D> Decode<___D> for LoaderLoadObjectResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
impl<___D> Decode<___D> for LoaderLoadObjectResponsewhere
___D: InternalHandleDecoder + ?Sized + HandleDecoder,
Sourceimpl<___E> Encode<LoaderLoadObjectResponse, ___E> for LoaderLoadObjectResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
impl<___E> Encode<LoaderLoadObjectResponse, ___E> for LoaderLoadObjectResponsewhere
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, LoaderLoadObjectResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, LoaderLoadObjectResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LoaderLoadObjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LoaderLoadObjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1> Encode<LoaderLoadObjectResponse, ___E> for LoaderLoadObjectResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Int32, ___E>,
T1: Encode<OptionalVmo, ___E>,
impl<___E, T0, T1> Encode<LoaderLoadObjectResponse, ___E> for LoaderLoadObjectResponse<T0, T1>where
___E: InternalHandleEncoder + ?Sized + HandleEncoder,
T0: Encode<Int32, ___E>,
T1: Encode<OptionalVmo, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<LoaderLoadObjectResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<LoaderLoadObjectResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<LoaderLoadObjectResponse> for LoaderLoadObjectResponse
impl FromWire<LoaderLoadObjectResponse> for LoaderLoadObjectResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<LoaderLoadObjectResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<LoaderLoadObjectResponse, Self>
Sourcefn from_wire(wire: LoaderLoadObjectResponse) -> Self
fn from_wire(wire: LoaderLoadObjectResponse) -> Self
Converts the given owned value to this type.
Sourceimpl IntoNatural for LoaderLoadObjectResponse
impl IntoNatural for LoaderLoadObjectResponse
Sourcetype Natural = LoaderLoadObjectResponse
type Natural = LoaderLoadObjectResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for LoaderLoadObjectResponse
impl Wire for LoaderLoadObjectResponse
Sourcetype Narrowed<'de> = LoaderLoadObjectResponse
type Narrowed<'de> = LoaderLoadObjectResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.